@@ -11,7 +11,6 @@ use bytes::Bytes;
 use ed25519_dalek::Keypair;
 use hex_fmt::HexFmt;
 pub use qp2p::{RecvStream, SendStream};
-use secured_linked_list::SecuredLinkedList;
 use sn_messaging::{client::ClientMsg, DstLocation, EndUser, SrcLocation};
 use std::{
     collections::BTreeSet,
@@ -67,8 +66,8 @@ pub enum Event {
         dst: DstLocation,
         /// The proof if the message was set to be aggregated at source.
         proof: Option<Proof>,
-        /// The proof chain for the message, if any.
-        proof_chain: Option<SecuredLinkedList>,
+        /// The Sender's Section PK.
+        section_pk: bls::PublicKey,
     },
     /// A new peer joined our section.
     MemberJoined {
