@@ -53,9 +53,10 @@ impl Core {
 
         // Check if the message is for us.
         let in_dst_location = msg.dst().contains(&self.node.name(), self.section.prefix());
-        if !in_dst_location || msg.dst().is_section() {
-            // Relay closer to the destination or
-            // broadcast to the rest of our section.
+        // TODO: Broadcast message to our section when src is a Node as nodes might not know
+        // all the elders in our section and the msg needs to be propagated.
+        if !in_dst_location {
+            info!("Relay closer to the destination");
             if let Some(cmds) = self.relay_message(&msg)? {
                 commands.push(cmds);
             }
@@ -69,9 +70,10 @@ impl Core {
             MessageStatus::Useful => {
                 trace!("Useful message from {:?}: {:?}", sender, msg);
                 let (entropy_commands, shall_be_handled) =
-                    self.check_for_entropy(&msg, dest_info.clone(), sender)?;
+                    self.check_for_entropy(&msg, dest_info.clone())?;
                 commands.extend(entropy_commands);
                 if shall_be_handled {
+                    info!("Entropy check passed. Handling useful msg!");
                     commands.extend(self.handle_useful_message(sender, msg, dest_info).await?);
                 }
             }
@@ -212,8 +214,12 @@ impl Core {
 
     pub(crate) fn handle_dkg_failure(&mut self, proofs: DkgFailureProofSet) -> Result<Command> {
         let variant = Variant::DkgFailureAgreement(proofs);
-        let message =
-            RoutingMsg::single_src(&self.node, DstLocation::DirectAndUnrouted, variant, None)?;
+        let message = RoutingMsg::single_src(
+            &self.node,
+            DstLocation::DirectAndUnrouted,
+            variant,
+            self.section.authority_provider().section_key,
+        )?;
         Ok(self.send_message_to_our_elders(message))
     }
 
@@ -401,7 +407,12 @@ impl Core {
             msg: Some(msg),
         };
 
-        let msg = RoutingMsg::single_src(self.node(), dst_location, variant, None)?;
+        let msg = RoutingMsg::single_src(
+            self.node(),
+            dst_location,
+            variant,
+            self.section.authority_provider().section_key,
+        )?;
         let key = self.section_key_by_name(&src_name);
         Ok(Command::send_message_to_node(
             (src_name, sender),
@@ -437,16 +448,20 @@ impl Core {
         content: Bytes,
     ) -> Result<Vec<Command>> {
         trace!("handle user message {:?}", msg);
-        if let DstLocation::EndUser(EndUser { xorname, socket_id }) = msg.dst() {
+        if let DstLocation::EndUser(EndUser {
+            xorname: xor_name,
+            socket_id,
+        }) = msg.dst()
+        {
             if let Some(socket_addr) = self.get_socket_addr(*socket_id).copied() {
                 trace!("sending user message {:?} to client {:?}", msg, socket_addr);
                 return Ok(vec![Command::SendMessage {
-                    recipients: vec![(*xorname, socket_addr)],
+                    recipients: vec![(*xor_name, socket_addr)],
                     delivery_group_size: 1,
                     message: MessageType::Client {
                         msg: ClientMsg::from(content)?,
                         dest_info: DestInfo {
-                            dest: *xorname,
+                            dest: *xor_name,
                             dest_section_pk: *self.section.chain().last_key(),
                         },
                     },
@@ -465,7 +480,7 @@ impl Core {
             src: msg.src.src_location(),
             dst: *msg.dst(),
             proof: msg.proof(),
-            proof_chain: msg.proof_chain().ok().cloned(),
+            section_pk: msg.section_pk(),
         })
         .await;
 
@@ -521,17 +536,6 @@ impl Core {
         self.update_state(snapshot).await
     }
 
-    pub fn handle_lagging_messages_on_sync(&mut self) -> Result<Vec<Command>> {
-        let mut commands = vec![];
-        let latest_key = *self.section_chain().last_key();
-        if let Some(lagged_commands) = self.lagging_messages.src_ahead.remove(&latest_key) {
-            // We now have the latest key, execute the messages that received when we were lagging.
-            commands.extend(lagged_commands);
-        }
-
-        Ok(commands)
-    }
-
     pub(crate) fn handle_join_request(
         &mut self,
         peer: Peer,
