@@ -21,6 +21,7 @@ use crate::{
     error::Result,
     event::{Elders, Event, NodeElderChange},
     message_filter::MessageFilter,
+    messages::RoutingMsgUtils,
     network::NetworkUtils,
     node::Node,
     relocation::RelocateState,
@@ -31,12 +32,10 @@ use itertools::Itertools;
 use resource_proof::ResourceProof;
 use secured_linked_list::SecuredLinkedList;
 use sn_messaging::{
-    node::{Network, Proposal, Proven, RoutingMsg, Section, SectionAuthorityProvider},
-    DestInfo, MessageId,
+    node::{Network, Proposal, Proven, RoutingMsg, Section, SectionAuthorityProvider, Variant},
+    DestInfo, DstLocation, MessageId,
 };
-use std::collections::BTreeMap;
 use std::collections::BTreeSet;
-use std::net::SocketAddr;
 use tokio::sync::mpsc;
 use xor_name::{Prefix, XorName};
 
@@ -62,13 +61,6 @@ pub(crate) struct Core {
     resource_proof: ResourceProof,
     end_users: EndUserRegistry,
     connectivity_complaints: ConnectivityComplaints,
-    lagging_messages: LaggingMessages,
-}
-
-#[derive(Default)]
-pub(crate) struct LaggingMessages {
-    // Execute upon sync
-    pub src_ahead: BTreeMap<bls::PublicKey, Vec<Command>>,
 }
 
 impl Core {
@@ -97,7 +89,6 @@ impl Core {
             resource_proof: ResourceProof::new(RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY),
             end_users: EndUserRegistry::new(),
             connectivity_complaints: ConnectivityComplaints::new(),
-            lagging_messages: LaggingMessages::default(),
         }
     }
 
@@ -113,7 +104,6 @@ impl Core {
         &mut self,
         msg: &RoutingMsg,
         dest_info: DestInfo,
-        sender: Option<SocketAddr>,
     ) -> Result<(Vec<Command>, bool)> {
         if !self.is_elder() {
             // Adult nodes do need to carry out entropy checking, however the message shall always
@@ -121,15 +111,8 @@ impl Core {
             return Ok((vec![], true));
         }
 
-        let (actions, can_be_executed) = anti_entropy::process(
-            &self.node,
-            &self.section,
-            &self.network,
-            &mut self.lagging_messages,
-            msg,
-            dest_info,
-            sender,
-        )?;
+        let (actions, can_be_executed) =
+            anti_entropy::process(&self.node, &self.section, msg, dest_info)?;
         let mut commands = vec![];
 
         for msg in actions.send {
@@ -194,11 +177,37 @@ impl Core {
                 }
 
                 self.print_network_stats();
+
+                // Sending SectionKnowledge to other sections for new SAP.
+                let section_auth = self.section.proven_authority_provider();
+                let variant = Variant::SectionKnowledge {
+                    src_info: (section_auth.clone(), self.section.chain().clone()),
+                    msg: None,
+                };
+                for sap in self.network.all() {
+                    let msg = RoutingMsg::single_src(
+                        &self.node,
+                        DstLocation::DirectAndUnrouted,
+                        variant.clone(),
+                        section_auth.value.section_key,
+                    )?;
+                    let targets: Vec<_> = sap
+                        .elders()
+                        .iter()
+                        .map(|(name, addr)| (*name, *addr))
+                        .collect();
+                    let len = targets.len();
+                    let dest_info = DestInfo {
+                        dest: XorName::random(),
+                        dest_section_pk: sap.section_key,
+                    };
+                    trace!("Sending updated SectionInfo to all known sections");
+                    commands.push(Command::send_message_to_nodes(targets, len, msg, dest_info));
+                }
             }
 
             if new.is_elder || old.is_elder {
                 commands.extend(self.send_sync(self.section.clone(), self.network.clone())?);
-                commands.extend(self.handle_lagging_messages_on_sync()?);
             }
 
             let current: BTreeSet<_> = self.section.authority_provider().names();
